from datetime import date, timedelta, timezone
from django.db import models

from django.db import models

class Account(models.Model):
    password = models.CharField(max_length=255)
    fullName = models.CharField(max_length=255)
    profession = models.CharField(max_length=255)
    interests = models.JSONField(default=list)
    wants = models.CharField(max_length=255)
    gender = models.CharField(max_length=10)
    bio = models.TextField()
    email = models.EmailField()
    phoneNumber = models.CharField(max_length=20)
    termsAccepted = models.BooleanField(default=False)
    photos = models.ImageField(upload_to='sm/account_photos/', null=True, blank=True)
    dob = models.DateField(default=date.today() - timedelta(days=18*365)) 
    created_at = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return self.fullName  # Customize to display meaningful info in admin panel
     

class Like(models.Model):
    sender = models.ForeignKey(Account, related_name='likes_sent', on_delete=models.CASCADE)
    receiver = models.ForeignKey(Account, related_name='likes_received', on_delete=models.CASCADE)
    is_like = models.BooleanField(default=True)
    created_at = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return f'{self.sender} liked {self.receiver} on {self.created_at}'
 
class RequestChat(models.Model):
    sender = models.ForeignKey(Account, related_name='chat_requests_sent', on_delete=models.CASCADE)
    receiver = models.ForeignKey(Account, related_name='chat_requests_received', on_delete=models.CASCADE)
    is_accepted = models.BooleanField(default=False)
    created_at = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return f'Request from {self.sender} to {self.receiver} at {self.created_at}'


from django.db import models
from django.utils import timezone
from django.utils.translation import gettext_lazy as _
from datetime import timedelta, datetime
import random
import string
from calendar import monthrange

class Payment(models.Model):
    STATUS_CHOICES = [
        ('complete', 'Complete'),
        ('incomplete', 'Incomplete'),
    ]

    user = models.ForeignKey(Account, related_name='payments', on_delete=models.CASCADE)
    plan = models.CharField(max_length=255)
    plan_expiry_time = models.DateTimeField()
    created_at = models.DateTimeField(auto_now_add=True)
    transaction_id = models.CharField(max_length=255, null=True, blank=True)
    is_active = models.BooleanField(default=True)
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    order_id = models.CharField(max_length=255)
    checkout_request_id = models.CharField(max_length=255, null=True, blank=True)
    status = models.CharField(max_length=10, choices=STATUS_CHOICES, default='complete')

    def __str__(self):
        return f'{self.user} - {self.plan} - {self.amount} - {self.status}'
 
from django.db import models 
class Transaction(models.Model):
    merchant_request_id = models.CharField(max_length=100)
    checkout_request_id = models.CharField(max_length=100)
    result_code = models.IntegerField()
    result_desc = models.CharField(max_length=255)
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    mpesa_receipt_number = models.CharField(max_length=100)
    transaction_date = models.CharField(max_length=100)
    phone_number = models.CharField(max_length=20)

    def __str__(self):
        return f"Transaction {self.id}"
